@@ -1,5 +1,5 @@
 
-if (file.exists("async")) {
+if (file.exists("async") && Sys.getenv("NOT_CRAN") == "true") {
   library(testthat)
   library(pkgcache)
   print(sessioninfo::package_info("pkgcache", dependencies = TRUE))
@@ -7,6 +7,6 @@ if (file.exists("async")) {
   test_dir(
     "async",
     env = new.env(parent = asNamespace("pkgcache")),
-    reporter = "check"
+    reporter = "summary"
   )
 }
